#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 isocline
version:              1.0.9
visibility:           public
id:                   isocline-1.0.9-2KCnLAEX6LA5YHxtEpLDUO
key:                  isocline-1.0.9-2KCnLAEX6LA5YHxtEpLDUO
license:              MIT
maintainer:           daan@effp.org
author:               Daan Leijen
homepage:             https://github.com/daanx/isocline#readme
synopsis:             A portable alternative to GNU Readline
description:
    ![logo](https://raw.githubusercontent.com/daanx/isocline/main/doc/isocline-inline.svg) A Haskell wrapper around the [Isocline C library](https://github.com/daanx/isocline#readme) which can provide an alternative to GNU Readline. (The Isocline library is included whole and there are no runtime dependencies).
    Please see the [readme](https://github.com/daanx/isocline/haskell#readme) on GitHub for more information.

category:             console
abi:                  7d0ebe5566f845c66793140e271e7814
exposed:              True
exposed-modules:      System.Console.Isocline
hidden-modules:       Paths_isocline
import-dirs:          /usr/lib/ghc-9.6.6/site-local/isocline-1.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/isocline-1.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/isocline-1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isocline
hs-libraries:         HSisocline-1.0.9-2KCnLAEX6LA5YHxtEpLDUO
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-isocline/html/isocline.haddock
haddock-html:         /usr/share/doc/haskell-isocline/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

